﻿// ----- Time-Based One-Time Password Example Application
//       Copyright (c) 2019 by Tim Patrick
//       Visit: www.owanipress.com/totp

using System.Windows;
using System.Windows.Input;

// This form's icon was created by Sebastian Rubio, as part of his Plateau Icons set.
//   http://www.iconarchive.com/show/plateau-icons-by-sbstnblnd/Apps-password-icon.html

namespace ExampleTOTP
{
    public partial class MainWindow : Window
    {
        private const string ProgramTitle = "Time-Based One-Time Password";

        public MainWindow()
        {
            InitializeComponent();
            this.DataContext = new MainWindowViewModel();
        }

        private void ActSignIn_Click(object sender, RoutedEventArgs e)
        {
            // ----- Sign in based on email address.
            MainWindowViewModel processing = (MainWindowViewModel)this.DataContext;
            if (processing.SignIn() == false)
                MessageBox.Show(processing.ErrorMessage,
                    ProgramTitle, MessageBoxButton.OK, MessageBoxImage.Exclamation);
        }

        private void ActShowQR_Click(object sender, RoutedEventArgs e)
        {
            // ----- Display the QR code of the active user.
            MainWindowViewModel processing = (MainWindowViewModel)this.DataContext;
            if (processing.DisplayQRCode() == false)
                MessageBox.Show(processing.ErrorMessage,
                    ProgramTitle, MessageBoxButton.OK, MessageBoxImage.Exclamation);
        }

        private void ActCheckPassCode_Click(object sender, RoutedEventArgs e)
        {
            // ----- Validate the provided pass code for ths user.
            MainWindowViewModel processing = (MainWindowViewModel)this.DataContext;
            if (processing.CheckPassCode() == false)
                MessageBox.Show(processing.ErrorMessage,
                    ProgramTitle, MessageBoxButton.OK, MessageBoxImage.Exclamation);
            else
                MessageBox.Show("Pass Code Accepted!",
                    ProgramTitle, MessageBoxButton.OK, MessageBoxImage.Exclamation);
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            // ----- Put cursor in email field on startup.
            MoveFocus(new TraversalRequest(FocusNavigationDirection.Next));
        }
    }
}
